@@ -2,9 +2,9 @@ use warnings;
 use strict;
 
 package MooseX::Has::Sugar;
-our $VERSION = '0.0405';
-
-
+BEGIN {
+  $MooseX::Has::Sugar::VERSION = '0.05044303';
+}
 
 # ABSTRACT: Sugar Syntax for moose 'has' fields
 
@@ -94,12 +94,12 @@ MooseX::Has::Sugar - Sugar Syntax for moose 'has' fields
 
 =head1 VERSION
 
-version 0.0405
+version 0.05044303
 
 =head1 SYNOPSIS
 
-L<Moose> C<has> syntax is generally fine, but sometimes one gets bothered with
-the constant typing of string quotes for things. L<MooseX::Types> exists and in
+L<Moose|Moose> C<has> syntax is generally fine, but sometimes one gets bothered with
+the constant typing of string quotes for things. L<The MooseX::Types module|MooseX::Types> exists and in
 many ways reduces the need for constant string creation.
 
 =head2 Primary Benefits at a Glance
@@ -173,7 +173,7 @@ Or even
 
 =head3 Basic C<is> Expansion Only
 
-( using L<MooseX::Has::Sugar::Minimal> instead )
+( using L<::Sugar::Minimal|MooseX::Has::Sugar::Minimal> instead )
 
     use MooseX::Types::Moose qw( Str );
     use MooseX::Has::Sugar::Minimal;
@@ -191,7 +191,7 @@ Or even
 
 =head3 Attribute Expansions with Basic Expansions
 
-( Combining parts of this and L<MooseX::Has::Sugar::Minimal> )
+( Combining parts of this and L<::Sugar::Minimal|MooseX::Has::Sugar::Minimal> )
 
     use MooseX::Types::Moose qw( Str );
     use MooseX::Has::Sugar::Minimal;
@@ -227,7 +227,7 @@ L</lazy> does.
             ro,
     );
 
-B<NOTE: This option is incompatible with L<MooseX::Has::Sugar::Minimal>> : L</CONFLICTS>
+B<NOTE: This option is incompatible with L<::Sugar::Minimal|MooseX::Has::Sugar::Minimal>> : L</CONFLICTS>
 
 =head2 :attrs
 
@@ -239,11 +239,11 @@ and L</auto_deref> as subs that assume positive.
             isa => 'Str',
     );
 
-B<NOTE: This option is incompatible with L<MooseX::Types> and L<Moose::Util::TypeConstraints>> : L</CONFLICTS>
+B<NOTE: This option is incompatible with L<MooseX::Types|MooseX::Types> and L<Moose's Type Constraints Module|Moose::Util::TypeConstraints>> : L</CONFLICTS>
 
 =head2 :is
 
-B<DEPRECATED>. See L<MooseX::Has::Sugar::Minimal> for the same functionality
+B<DEPRECATED>. See L<::Sugar::Minimal|MooseX::Has::Sugar::Minimal> for the same functionality
 
 =head2 :allattrs
 
@@ -285,7 +285,7 @@ returns C<('weak_ref',1)>
 
 returns C<('coerce',1)>
 
-B<WARNING:> Conflict with L<MooseX::Types> and L<Moose::Util::TypeConstraints>, see L<CONFLICTS>.
+B<WARNING:> Conflict with L<MooseX::Types|MooseX::Types> and L<Moose::Util::TypeConstraints|Moose::Util::TypeConstraints>, see L</CONFLICTS>.
 
 =head2 auto_deref
 
@@ -298,7 +298,7 @@ returns C<('auto_deref',1)>
 =head2 MooseX::Has::Sugar::Saccharin
 
 This module is not intended to be used in conjunction with
- L<MooseX::Has::Sugar::Minimal> or L<MooseX::Has::Sugar::Saccharin>
+ L<::Sugar::Minimal|MooseX::Has::Sugar::Minimal> or L<::Sugar::Saccharin|MooseX::Has::Sugar::Saccharin>
 
 We export many of the same symbols and its just not very sensible.
 
@@ -319,11 +319,11 @@ We recommend using and creating proper type libraries instead, ( which will abso
 
 =head1 AUTHOR
 
-  Kent Fredric <kentnl at cpan.org>
+Kent Fredric <kentnl at cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Kent Fredric.
+This software is copyright (c) 2010 by Kent Fredric.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
